(*********************************************************)
(* TSLXFilterData class for TSLXFilter component         *)
(* distributed for free, non-commercial purpose          *)
(*  2007 by Sl-Alex http://www.sl-alex.nm.ru/           *)
(*********************************************************)
unit FilterData;

interface

uses Classes;

type
TSLXFilterData = class(TPersistent)
  private
    FOwner: TComponent;
    FDataList: TList;
    function FGetDataCount: Integer;
    function FGetDataItem(const AIndex: Integer): Double;
    procedure FSetDataItem(const AIndex: Integer; NewValue: Double);
  public
    constructor Create(AOwner: TComponent);
    destructor Destroy; override;
    property Items[const AIndex: Integer]: Double read FGetDataItem write FSetDataItem;
    procedure AddData(Value: Double);
    procedure InitData(Value: Double);
    procedure Clear;
  published
    property Count: Integer read FGetDataCount;
end;

implementation

uses Filter;

constructor TSLXFilterData.Create(AOwner: TComponent);
begin
  inherited Create;
  FDataList:=TList.Create;
  FOwner:=AOwner;
end;

destructor TSLXFilterData.Destroy;
begin
  Clear;
  FDataList.Destroy;
  inherited Destroy;
end;

procedure TSLXFilterData.AddData(Value: Double);
begin
  TSLXFilterPoint(FDataList.Items[0]).Destroy;
  FDataList.Delete(0);
  FDataList.Add(TSLXFilterPoint.Create(Value));
  (FOwner as TSLXFilter).CalcOut;
end;

//     
procedure TSLXFilterData.InitData(Value: Double);
var i: Integer;
    DataCount: Integer;
begin
  Clear;
  DataCount:=(FOwner as TSLXFilter).Length;
  for i:=0 to DataCount-1 do begin
    FDataList.Add(TSLXFilterPoint.Create(Value));
  end;
end;

procedure TSLXFilterData.Clear;
var i: Integer;
begin
  for i:=0 to FDataList.Count-1 do begin
    TSLXFilterPoint(FDataList.Items[i]).Destroy;
  end;
  FDataList.Clear;
end;

function TSLXFilterData.FGetDataCount: Integer;
begin
  FGetDataCount:=FDataList.Count;
end;

//procedure TSLXFilterData.FAddData(Value: Double);
//begin
//  FDataList.Add(TSLXFilterPoint.Create(Value));
//end;

function TSLXFilterData.FGetDataItem(const AIndex: Integer): Double;
begin
  FGetDataItem:=TSLXFilterPoint(FDataList.Items[AIndex]).Value;
end;

procedure TSLXFilterData.FSetDataItem(const AIndex: Integer; NewValue: Double);
begin
//
end;

end.
